@@ -1,34 +1,20 @@
 /*
- *  Copyright 2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "documenttypeswidget.h"
-#include "nodetypesdelegate.h"
 #include "edgetypesdelegate.h"
 #include "libgraphtheory/nodetype.h"
+#include "nodetypesdelegate.h"
 #include <KLocalizedString>
 #include <KWidgetItemDelegate>
+#include <QDebug>
 #include <QGridLayout>
+#include <QLabel>
 #include <QListView>
 #include <QPushButton>
-#include <QLabel>
-#include <QDebug>
 
 using namespace GraphTheory;
 
@@ -51,12 +37,9 @@ DocumentTypesWidget::DocumentTypesWidget(QWidget *parent)
     nodeTypeView->setModel(&m_nodeTypeModel);
     layout->addWidget(nodeTypeView);
 
-    connect(nodeDelegate, &NodeTypesDelegate::colorChanged,
-        this, &DocumentTypesWidget::onNodeTypeColorChanged);
-    connect(nodeDelegate, &NodeTypesDelegate::nameChanged,
-        this, &DocumentTypesWidget::onNodeTypeNameChanged);
-    connect(m_createNodeTypeButton, &QPushButton::clicked,
-        this, &DocumentTypesWidget::onCreateNodeType);
+    connect(nodeDelegate, &NodeTypesDelegate::colorChanged, this, &DocumentTypesWidget::onNodeTypeColorChanged);
+    connect(nodeDelegate, &NodeTypesDelegate::nameChanged, this, &DocumentTypesWidget::onNodeTypeNameChanged);
+    connect(m_createNodeTypeButton, &QPushButton::clicked, this, &DocumentTypesWidget::onCreateNodeType);
 
     // edge types
     layout->addWidget(new QLabel(i18nc("@title", "Edge Types")));
@@ -70,14 +53,10 @@ DocumentTypesWidget::DocumentTypesWidget(QWidget *parent)
     edgeTypeView->setModel(&m_edgeTypeModel);
     layout->addWidget(edgeTypeView);
 
-    connect(edgeDelegate, &EdgeTypesDelegate::colorChanged,
-        this, &DocumentTypesWidget::onEdgeTypeColorChanged);
-    connect(edgeDelegate, &EdgeTypesDelegate::nameChanged,
-        this, &DocumentTypesWidget::onEdgeTypeNameChanged);
-    connect(edgeDelegate, &EdgeTypesDelegate::directionChanged,
-        this, &DocumentTypesWidget::onEdgeTypeDirectionChanged);
-    connect(m_createEdgeTypeButton, &QPushButton::clicked,
-        this, &DocumentTypesWidget::onCreateEdgeType);
+    connect(edgeDelegate, &EdgeTypesDelegate::colorChanged, this, &DocumentTypesWidget::onEdgeTypeColorChanged);
+    connect(edgeDelegate, &EdgeTypesDelegate::nameChanged, this, &DocumentTypesWidget::onEdgeTypeNameChanged);
+    connect(edgeDelegate, &EdgeTypesDelegate::directionChanged, this, &DocumentTypesWidget::onEdgeTypeDirectionChanged);
+    connect(m_createEdgeTypeButton, &QPushButton::clicked, this, &DocumentTypesWidget::onCreateEdgeType);
 
     setLayout(layout);
     show();
@@ -98,7 +77,7 @@ void DocumentTypesWidget::onNodeTypeColorChanged(const QModelIndex &index, const
     m_nodeTypeModel.setData(index, QVariant::fromValue<QColor>(color), NodeTypeModel::ColorRole);
 }
 
-void DocumentTypesWidget::onNodeTypeNameChanged(const QModelIndex& index, const QString& name)
+void DocumentTypesWidget::onNodeTypeNameChanged(const QModelIndex &index, const QString &name)
 {
     m_nodeTypeModel.setData(index, QVariant(name), NodeTypeModel::TitleRole);
 }
@@ -114,12 +93,12 @@ void DocumentTypesWidget::onEdgeTypeColorChanged(const QModelIndex &index, const
     m_edgeTypeModel.setData(index, QVariant::fromValue<QColor>(color), EdgeTypeModel::ColorRole);
 }
 
-void DocumentTypesWidget::onEdgeTypeNameChanged(const QModelIndex& index, const QString& name)
+void DocumentTypesWidget::onEdgeTypeNameChanged(const QModelIndex &index, const QString &name)
 {
     m_edgeTypeModel.setData(index, QVariant(name), EdgeTypeModel::TitleRole);
 }
 
-void DocumentTypesWidget::onEdgeTypeDirectionChanged(const QModelIndex& index, const EdgeType::Direction& direction)
+void DocumentTypesWidget::onEdgeTypeDirectionChanged(const QModelIndex &index, const EdgeType::Direction &direction)
 {
     m_edgeTypeModel.setData(index, direction, EdgeTypeModel::DirectionRole);
 }
